==> haskell-monads-tf-0.1.0.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monads-tf
version: 0.1.0.3
id: monads-tf-0.1.0.3-HVD88uwypLB1Pu4HQI1mbn
key: monads-tf-0.1.0.3-HVD88uwypLB1Pu4HQI1mbn
license: BSD3
maintainer: Ross Paterson <ross@soi.city.ac.uk>
synopsis: Monad classes, using type families
description:
    Monad classes using type families, with instances for various
    monad transformers, inspired by the paper /Functional Programming
    with Overloading and Higher-Order Polymorphism/, by Mark P
    Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
    .
    This package is almost a compatible replacement for the @mtl-tf@ package.
category: Control
author: Andy Gill
exposed: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Identity Control.Monad.List
    Control.Monad.RWS Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: 82d14678ccd630cf7381539de5d8a96f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monads-tf-0.1.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/monads-tf-0.1.0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/monads-tf-0.1.0.3
hs-libraries: HSmonads-tf-0.1.0.3-HVD88uwypLB1Pu4HQI1mbn
depends:
    base-4.9.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html: /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monads-tf-0.1.0.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monads-tf
version: 0.1.0.3
id: monads-tf-0.1.0.3-JIPNoZ6aJW379YQZJvMYoR
key: monads-tf-0.1.0.3-JIPNoZ6aJW379YQZJvMYoR
license: BSD3
maintainer: Ross Paterson <ross@soi.city.ac.uk>
synopsis: Monad classes, using type families
description:
    Monad classes using type families, with instances for various
    monad transformers, inspired by the paper /Functional Programming
    with Overloading and Higher-Order Polymorphism/, by Mark P
    Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
    .
    This package is almost a compatible replacement for the @mtl-tf@ package.
category: Control
author: Andy Gill
exposed: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Identity Control.Monad.List
    Control.Monad.RWS Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: 27140f361fe13c8ae1977b4ad7ea9255
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/monads-tf-0.1.0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/monads-tf-0.1.0.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/monads-tf-0.1.0.3
hs-libraries: HSmonads-tf-0.1.0.3-JIPNoZ6aJW379YQZJvMYoR
depends:
    base-4.9.1.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html: /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
